package com.supervision.controller;

import com.supervision.model.ProcessMedical;
import com.supervision.service.MedicalRecordService;
import com.supervision.vo.ask.ProcessMedicalResVo;
import com.supervision.vo.ask.ProcessMedicalViewDetailResVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;


@Slf4j
@Api(tags = "电子病例")
@RestController
@RequestMapping("medicalRecord")
@RequiredArgsConstructor
public class MedicalRecordController {

    private final MedicalRecordService medicalRecordService;

    @ApiOperation("新增电子病例信息")
    @PostMapping("save")
    public boolean saveMedicalRecord(@RequestBody ProcessMedical processMedical){

        return medicalRecordService.saveMedicalRecord(processMedical);
    }

    @ApiOperation("更新电子病例信息")
    @PutMapping("update")
    public boolean updateMedicalRecord(@RequestBody ProcessMedical processMedical){

        return medicalRecordService.updateMedicalRecord(processMedical);
    }

    @ApiOperation("通过流程id查询电子病例信息")
    @GetMapping("findByProcessId")
    public ProcessMedicalResVo findByProcessId(@ApiParam("流程id") @RequestParam("processId") String processId){

        return medicalRecordService.findByProcessId(processId);
    }


    @ApiOperation("电子病例视图")
    @GetMapping("queryViewDetails")
    public ProcessMedicalViewDetailResVo queryViewDetail(@ApiParam("流程id") @RequestParam("processId") String processId){

        return medicalRecordService.queryViewDetail(processId);
    }
}
